diff --git a/doc/src/sgml/logicaldecoding.sgml b/doc/src/sgml/logicaldecoding.sgml
index d2c6e15..250cd9b 100644
--- a/doc/src/sgml/logicaldecoding.sgml
+++ b/doc/src/sgml/logicaldecoding.sgml
@@ -1066,18 +1066,55 @@ OutputPluginWrite(ctx, true);
 
   <sect1 id="logicaldecoding-synchronous">
    <title>Synchronous Replication Support for Logical Decoding</title>
+   <sect2>
+     <title>Overview</title>
 
-   <para>
-    Logical decoding can be used to build
-    <link linkend="synchronous-replication">synchronous
-    replication</link> solutions with the same user interface as synchronous
-    replication for <link linkend="streaming-replication">streaming
-    replication</link>.  To do this, the streaming replication interface
-    (see <xref linkend="logicaldecoding-walsender"/>) must be used to stream out
-    data. Clients have to send <literal>Standby status update (F)</literal>
-    (see <xref linkend="protocol-replication"/>) messages, just like streaming
-    replication clients do.
-   </para>
+     <indexterm>
+       <primary>Overview</primary>
+     </indexterm>
+
+     <para>
+       Logical decoding can be used to build
+       <link linkend="synchronous-replication">synchronous
+         replication</link> solutions with the same user interface as synchronous
+       replication for <link linkend="streaming-replication">streaming
+         replication</link>.  To do this, the streaming replication interface
+       (see <xref linkend="logicaldecoding-walsender"/>) must be used to stream out
+       data. Clients have to send <literal>Standby status update (F)</literal>
+       (see <xref linkend="protocol-replication"/>) messages, just like streaming
+       replication clients do.
+     </para>
+   </sect2>
+
+   <sect2 id ="logicaldecoding-synchronous-caveats">
+     <title>Caveats</title>
+     <indexterm>
+       <primary>Caveats</primary>
+     </indexterm>
+
+     <para>
+       The use of any command to take an ACCESS EXCLUSIVE lock on [user] catalog tables
+       can cause the deadlock of logical decoding in synchronous mode. This means that
+       at the transaction commit or prepared transaction, the command hangs or the server
+       becomes to block any new connections, even after the server restart. To avoid this,
+       users must refrain from such operations.
+       
+       When <command>COMMIT</command> is conducted for a transaction that has
+       issued explicit <command>LOCK</command> with logical decoding, the deadlock occurs.
+       Also, committing one that runs <command>CLUSTER</command> pg_class and
+       some logical decoding operations is another deadlock scenario.
+       
+       Additionally, executing <command>PREPARE TRANSACTION</command>
+       after <command>LOCK</command> command on <structname>pg_class</structname> and
+       logical decoding of published table within the same transaction leads to a hang.
+       Similarly, clustering <structname>pg_trigger</structname> by <command>
+         CLUSTER</command> command brings about the deadlock, when published table has a
+       trigger and any operations that will be decoded are conducted on the same table.
+       
+       Finally, the deadlock can happen when users execute <command>TRUNCATE</command>
+       on user_catalog_table under the condition that output plugin have a reference to it.
+     </para>
+   </sect2>
 
    <note>
     <para>
@@ -1253,9 +1290,11 @@ stream_commit_cb(...);  &lt;-- commit of the streamed transaction
       <para>
        The logical replication solution that builds distributed two phase commit
        using this feature can deadlock if the prepared transaction has locked
-       [user] catalog tables exclusively. They need to inform users to not have
-       locks on catalog tables (via explicit <command>LOCK</command> command) in
-       such transactions.
+       [user] catalog tables exclusively. To avoid this users must refrain from
+       having locks on catalog tables (e.g. explicit <command>LOCK</command> command)
+       in such transactions.
+       (See <link linkend="logicaldecoding-synchronous-caveats">Synchronous
+          Replication Support for Logical Decoding</link> for the details.)
       </para>
      </listitem>
     </itemizedlist>
